==> arirang-1.90.tar.gz: arirang-1.90/screen.c <==
/*
 * Copyright 2001-2002, 2010 pilot <pilot@monkey.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/utsname.h>

#include <stdio.h>
#include <stdlib.h>

#include "arirang.h"
#include "version.h"

void
scrview(void)
{
    struct utsname  uts;
    uname(&uts);
    
    fprintf(stdout, "\033[0;32m%s \033[0m\033[0;35m  arirang %s for %s (%s)\033[0m \033[0m\n",
        TITLE, VERSION, uts.sysname, uts.machine);
    fprintf(stdout, "(c)2001,2002, 2010 by pilot released %s   powered by twwwscan\n\n", RELEASE_DATE);
}

void
usage(void)
{
    scrview();

    fprintf(stdout, "usage        : arirang [-t] [-w] [-S] [-GO] [-p] [-hfs] [-e] [-r] [-v] [-P]    \n");
    fprintf(stdout, "<timeout>    : -t  socket receive timeout (default 5)                          \n");
    fprintf(stdout, "<html>       : -w  arirang scan result to html format                          \n");
    fprintf(stdout, "<SSL>        : -S  use the SSL (default 443/tcp)                               \n");
    fprintf(stdout, "<finger>     : -O  check the allow option of webserver                         \n");
    fprintf(stdout, "               -G  check server of webserver                                   \n");
    fprintf(stdout, "<port>       : -p  webserver running port                                      \n");
    fprintf(stdout, "<scan type>  : -h  one host scan or CIDR scan                                  \n");
    fprintf(stdout, "             : -f  scan hosts list file                                        \n");
    fprintf(stdout, "             : -s  wide network scan  start ip                                 \n");
    fprintf(stdout, "             : -e  wide network scan  end   ip                                 \n");
    fprintf(stdout, "<scan rule>  : -r  arirang scan rule databases(.uxe)                           \n");
    fprintf(stdout, "<virtual>    : -v  virtual host scan and http 1.1                              \n");
    fprintf(stdout, "<process>    : -P  max process count (default file, wide 30, normal 0)       \n\n");
    fprintf(stdout, "<examples>                                                                     \n");
    fprintf(stdout, "check server : arirang -G -h 127.0.0.1                                         \n");
    fprintf(stdout, "check allow  : arirang -O -h yourhost                                          \n");
    fprintf(stdout, "server port  : arirang -G -p 8080 -h yourhost                                  \n");
    fprintf(stdout, "ssl scan     : arirang -S -G -s 192.168.1.1 -e 192.168.1.100                   \n");
    fprintf(stdout, "virtual      : arirang -G -h virtual_host -r test.uxe -v                       \n");
    fprintf(stdout, "scan hosts   : arirang -G -f scanlist_file                                     \n");
    fprintf(stdout, "wide         : arirang -O -h 192.168.1.1/24                                    \n");
    fprintf(stdout, "               arirang -G -h yourdomain/24                                     \n");
    fprintf(stdout, "               arirang -G -s 192.168.1.1 -e 192.168.2.255                      \n");
    fprintf(stdout, "scan rule    : arirang -O -h yourhost -r unix.uxe                              \n");
    fprintf(stdout, "fast scan    : arirang -S -G -h yourhost -r nt.uxe -P 50                       \n");
    fprintf(stdout, "               arirang -G -f scanlist_file -r unicode.uxe -P 50                \n");
    fprintf(stdout, "               arirang -t 2 -G -s 192.168.1.1 -e 192.168.2.255 -r nt.uxe       \n");
    fprintf(stdout, "               arirang -G -s 192.168.1.1 -e 192.168.1.255 -r codered.uxe -P 60 \n");
    fprintf(stdout, "               arirang -S -G -h yourdomain/24 -r scanrule/request.uxe -P 60    \n");
    fprintf(stdout, "html report  : arirang -w report.html -G -h yourhost/24 -r scanrule/request.uxe\n");
    fprintf(stdout, "               arirang -w result.html -S -O -h 192.168.1.1/16 -P 60            \n");
    fprintf(stdout, "               arirang -w result.html -G -s 192.168.1.1 -e 192.168.1.100     \n\n");
    fprintf(stdout, "contact      : pilot@monkey.org    http://www.monkey.org/~pilot              \n\n");
    fprintf(stdout, "thanks to r0ar,a_a_a,apl,BK,chute,parasol,bitrider,chaeso,*^^*,kuol            \n");
    fprintf(stdout, "Dug Song(monkey.org),UNYUN(Shadow Penguin Security),Roelof(www.sensepost.com)  \n");
    fprintf(stdout, "David(A.K.A AnOnYmUs),friends(dhartmei,fgsch,ActivatE,obecian,jeremie,Lupines) \n"); 
    fprintf(stdout, "Hong Gil-Dong, Jeon Woo-Chi and contributors.                                \n\n");
    fprintf(stdout, "tested on %s\n\n", TESTED_OS);
    exit(1);
}

==> arirang-1.95.tar.gz: arirang-1.95/screen.c <==
/*
 * Copyright 2001-2002, 2010 pilot <pilot@monkey.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/utsname.h>

#include <stdio.h>
#include <stdlib.h>

#include "arirang.h"
#include "version.h"

void
scrview(void)
{
    struct utsname  uts;
    uname(&uts);
    
    fprintf(stdout, "\033[0;32m%s \033[0m\033[0;35m  arirang %s for %s (%s)\033[0m \033[0m\n",
        TITLE, VERSION, uts.sysname, uts.machine);
    fprintf(stdout, "(c)2001,2002, 2010 by pilot released %s   powered by twwwscan\n\n", RELEASE_DATE);
}

void
usage(void)
{
    scrview();

    fprintf(stdout, "usage        : arirang [-t] [-w] [-S] [-RGO] [-p] [-hfs] [-e] [-r] [-v] [-P]   \n");
    fprintf(stdout, "<timeout>    : -t  socket receive timeout (default 5)                          \n");
    fprintf(stdout, "<html>       : -w  arirang scan result to html format                          \n");
    fprintf(stdout, "<SSL>        : -S  use the SSL (default 443/tcp)                               \n");
    fprintf(stdout, "<script>     : -R  arirang Ruby script (only scan type, not scan rule)         \n");
    fprintf(stdout, "<finger>     : -O  check the allow option of webserver                         \n");
    fprintf(stdout, "               -G  check server of webserver                                   \n");
    fprintf(stdout, "<port>       : -p  webserver running port                                      \n");
    fprintf(stdout, "<scan type>  : -h  one host scan or CIDR scan                                  \n");
    fprintf(stdout, "             : -f  scan hosts list file                                        \n");
    fprintf(stdout, "             : -s  wide network scan  start ip                                 \n");
    fprintf(stdout, "             : -e  wide network scan  end   ip                                 \n");
    fprintf(stdout, "<scan rule>  : -r  arirang scan rule databases(.uxe)                           \n");
    fprintf(stdout, "<virtual>    : -v  virtual host scan and http 1.1                              \n");
    fprintf(stdout, "<process>    : -P  max process count (default file, wide 30, normal 0)       \n\n");
    fprintf(stdout, "<examples>                                                                     \n");
    fprintf(stdout, "check server : arirang -G -h 127.0.0.1                                         \n");
    fprintf(stdout, "check allow  : arirang -O -h yourhost                                          \n");
    fprintf(stdout, "server port  : arirang -G -p 8080 -h yourhost                                  \n");
    fprintf(stdout, "script       : arirang -R script/server.rb -h yourhost/24                      \n");
    fprintf(stdout, "             : arirang -S -R script/allow.rb -h 192.168.0.1/16 -P 60           \n");
    fprintf(stdout, "ssl scan     : arirang -S -G -s 192.168.1.1 -e 192.168.1.100                   \n");
    fprintf(stdout, "virtual      : arirang -G -h virtual_host -r test.uxe -v                       \n");
    fprintf(stdout, "scan hosts   : arirang -G -f scanlist_file                                     \n");
    fprintf(stdout, "wide         : arirang -O -h 192.168.1.1/24                                    \n");
    fprintf(stdout, "               arirang -G -h yourdomain/24                                     \n");
    fprintf(stdout, "               arirang -G -s 192.168.1.1 -e 192.168.2.255                      \n");
    fprintf(stdout, "scan rule    : arirang -O -h yourhost -r unix.uxe                              \n");
    fprintf(stdout, "fast scan    : arirang -S -G -h yourhost -r nt.uxe -P 50                       \n");
    fprintf(stdout, "               arirang -G -f scanlist_file -r unicode.uxe -P 50                \n");
    fprintf(stdout, "               arirang -t 2 -G -s 192.168.1.1 -e 192.168.2.255 -r nt.uxe       \n");
    fprintf(stdout, "               arirang -G -s 192.168.1.1 -e 192.168.1.255 -r codered.uxe -P 60 \n");
    fprintf(stdout, "               arirang -S -G -h yourdomain/24 -r scanrule/request.uxe -P 60    \n");
    fprintf(stdout, "html report  : arirang -w report.html -G -h yourhost/24 -r scanrule/request.uxe\n");
    fprintf(stdout, "               arirang -w result.html -S -O -h 192.168.1.1/16 -P 60            \n");
    fprintf(stdout, "               arirang -w result.html -G -s 192.168.1.1 -e 192.168.1.100     \n\n");
    fprintf(stdout, "contact      : pilot@monkey.org    http://www.monkey.org/~pilot              \n\n");
    fprintf(stdout, "thanks to r0ar,a_a_a,apl,BK,chute,parasol,bitrider,chaeso,*^^*,kuol            \n");
    fprintf(stdout, "Dug Song(monkey.org),UNYUN(Shadow Penguin Security),Roelof(www.sensepost.com)  \n");
    fprintf(stdout, "David(A.K.A AnOnYmUs),friends(dhartmei,fgsch,ActivatE,obecian,jeremie,Lupines) \n"); 
    fprintf(stdout, "Hong Gil-Dong, Jeon Woo-Chi and contributors.                                \n\n");
    fprintf(stdout, "tested on %s\n\n", TESTED_OS);
    exit(1);
}
